{ pkgs, ... }:

{
  home.username = "mrflos";
  home.homeDirectory = "/home/mrflos";
  home.stateVersion = "24.05"; # Please read the comment before changing.
  home.packages = with pkgs; [
    ansible
    atuin
    bat
    black
    btop
    cargo
    catnip
    cmatrix
    coreutils
    curl
    dnsutils
    emacs-nox
    fd
    findutils
    fish
    fzf
    gcc
    gnugrep
    gnumake
    gnupg
    go
    imagemagick
    jq
    git
    glances
    htop
    lazygit
    lsd
    magic-wormhole
    lua51Packages.lua
    lua51Packages.luarocks
    lua-language-server
    mc
    micro
    mosh
    mpd
    mpv
    neofetch
    neovim
    nil
    nixd
    nixfmt-rfc-style
    nodejs_20
    pandoc
    pass
    pciutils
    php83
    php83Packages.composer
    php83Packages.php-cs-fixer
    phpactor
    pinentry
    python312
    python312Packages.pip
    python312Packages.python-lsp-server
    ripgrep
    slides
    starship
    symfony-cli
    tailwindcss-language-server
    tmux
    tree
    unzip
    usbutils
    wget
    whois
    wirelesstools
    yarn
    yazi
    yt-dlp
    zellij
    zoxide
    zola
    zsh-autosuggestions

    # fonts
    (pkgs.nerdfonts.override { fonts = [ "Iosevka" ]; })
  ];

  home.file = {
    "./.config/kitty/" = {
      source = ../dotfiles/kitty;
      recursive = true;
    };

    "./.config/nvim/" = {
      source = ../dotfiles/nvim;
      recursive = true;
    };

    "./.config/lazygit/" = {
      source = ../dotfiles/lazygit;
      recursive = true;
    };

    "./.config/tmux/" = {
      source = ../dotfiles/tmux;
      recursive = true;
    };
  };
  home.sessionVariables = {
    EDITOR = "nvim";
  };
  home.sessionPath = [
    "$HOME/.local/bin"
    "$HOME/go/bin"
  ];
  accounts.email.accounts = {
    "mrflos@chmok.net" = {
      realName = "Florian Schmitt";
      userName = "mrflos@chmok.net";
      address = "mrflos@chmok.net";

      primary = true;
      thunderbird = {
        enable = true;
      };
      imap = {
        host = "mail.infomaniak.com";
        port = 993;
      };

      smtp = {
        host = "mail.infomaniak.com";
        port = 465;
      };
    };
    "mrflos@yeswiki.pro" = {
      realName = "Florian Schmitt - Yeswiki.pro";
      userName = "mrflos@yeswiki.pro";
      address = "mrflos@yeswiki.pro";

      thunderbird = {
        enable = true;
      };
      imap = {
        host = "mail.infomaniak.com";
        port = 993;
      };

      smtp = {
        host = "mail.infomaniak.com";
        port = 465;
      };
    };
    "mrflos@mrflos.pw" = {
      realName = "Florian Schmitt";
      userName = "mrflos";
      address = "mrflos@mrflos.pw";

      primary = false;
      thunderbird = {
        enable = true;
      };
      imap = {
        host = "mrflos.pw";
        port = 993;
        #tls.enable = true;
        #tls.useStartTls = true;
      };

      smtp = {
        host = "mrflos.pw";
        port = 587;
        #tls.useStartTls = true;
      };
    };
    "contact@yeswiki.pro" = {
      realName = "YesWiki.pro";
      userName = "contact@yeswiki.pro";
      address = "contact@yeswiki.pro";

      primary = false;
      thunderbird = {
        enable = true;
      };
      imap = {
        host = "mail.infomaniak.com";
        port = 993;
      };

      smtp = {
        host = "mail.infomaniak.com";
        port = 465;
      };
    };
    "contact@yeswiki.net" = {
      realName = "YesWiki.net";
      userName = "contact@yeswiki.net";
      address = "contact@yeswiki.net";

      primary = false;
      thunderbird = {
        enable = true;
      };
      imap = {
        host = "mail.infomaniak.com";
        port = 993;
      };

      smtp = {
        host = "mail.infomaniak.com";
        port = 465;
      };
    };
  };

  programs = {
    direnv = {
      enable = true;
      enableZshIntegration = true;
      nix-direnv.enable = true;
    };

    git = {
      enable = true;
      userName = "Florian Schmitt";
      userEmail = "mrflos@gmail.com";
      aliases = {
        fa = "fetch --all --tags --prune --recurse-submodules --force";
      };
      extraConfig = {
        pull.rebase = true;
        init.defaultBranch = "main";
        core.editor = "nvim";
        core.fileMode = false;
      };
    };

    neovim = {
      defaultEditor = true;
      viAlias = true;
      vimAlias = true;
    };

    starship = {
      enable = true;
      settings = with builtins; fromTOML (readFile ../dotfiles/starship/starship.toml);
    };

    zsh = {
      enable = true;
      autosuggestion.enable = true;
      enableCompletion = true;
      shellAliases = {
        #tmux = "tmux -f ~/.config/tmux/tmux.conf attach || tmux -f ~/.config/tmux/tmux.conf new";
        bunx = "bun --bun x";
        g = "lazygit";
        kdenix = "nix run github:pjones/plasma-manager --extra-experimental-features nix-command --extra-experimental-features flakes > /home/mrflos/Developpements/nixos-config/modules/home-plasma.nix";
        icat = "kitty +kitten icat";
        nixedit = "vi /etc/nixos";
        nixupdate = "sudo nix-channel --update && sudo nixos-rebuild switch";
        nixclean = "sudo nix-env --delete-generations old --profile /nix/var/nix/profiles/system && sudo /nix/var/nix/profiles/system/bin/switch-to-configuration switch && sudo nix-store --gc";
        socks = "ssh -N -f -C -D 9090 mrflos@yunohost.yeswiki.net -p 6742";
        yeswiki-updater = "cd /home/mrflos/Developpements/yeswiki-installer/ && sudo php yeswiki-updater.php";
        vi = "nvim";
        vim = "nvim";
      };
      initExtra = ''
        export BUN_INSTALL="$HOME/.bun"
        export PHP_CS_FIXER_IGNORE_ENV=1
        export PATH="$HOME/.local/bin:$BUN_INSTALL/bin:$PATH"
        eval "$(atuin init zsh)"
        eval "$(zoxide init zsh)"
      '';
      oh-my-zsh = {
        enable = true;
        extraConfig = ''
          zstyle :omz:plugins:ssh-agent helper ksshaskpass
          zstyle :omz:plugins:ssh-agent agent-forwarding yes
          zstyle :omz:plugins:ssh-agent lazy yes
        '';
        plugins = [
          "git"
          "ssh-agent"
        ];
        #  theme = "robbyrussell";
      };
    };
  };

  services.ssh-agent.enable = true;
  programs.home-manager.enable = true;
}
